@@ -30,6 +30,19 @@ if not os.path.exists(se_file):
    data = open(se_file, 'w')
    cPickle.dump(default, data)
    data.close()
+
+css_file = '%s/.mozilla/microb/chrome/userContent.css' % HOME
+if not os.path.exists(css_file):
+   f = open(css_file, 'w')
+   f.close()
+   
+f = open(css_file, 'r')
+css_file_contents = f.read()
+if css_file_contents.find('@import url("touchsearch.css");') == -1:
+   f.close()
+   f = open(css_file, 'a')
+   f.write('\n@import url("touchsearch.css");')
+   f.close()
    
 
 class TouchSearch(hildondesktop.HomePluginItem):
